@@ -287,7 +287,7 @@ static int _ggi_xshm_create_ximage(ggi_visual *vis)
 	_ggi_build_pixfmtstr(vis, target + i, sizeof(target) - i, 1);
 	i = strlen(target);
 #ifdef HAVE_SNPRINTF
-	snprintf(target + i, GGI_MAX_APILEN, ":-layout=%iplb%i:-physz=%i,%i:pointer",
+	snprintf(target + i, GGI_MAX_APILEN - i, ":-layout=%iplb%i:-physz=%i,%i:pointer",
 		priv->ximage->bytes_per_line * LIBGGI_VIRTY(vis),
 		priv->ximage->bytes_per_line,
 		LIBGGI_MODE(vis)->size.x, LIBGGI_MODE(vis)->size.y);
