@@ -1,4 +1,4 @@
-/* $Id: teleserver.c,v 1.1.2.1 2004/11/14 00:40:42 cegger Exp $
+/* $Id$
 ******************************************************************************
 
    TELE SERVER.
@@ -487,8 +487,8 @@ static void perf_GETBOX(TeleUser *u, TeleEvent *ev)
 	uint8 *dest;
 
 	if ((d->x < 0) || (d->y < 0) ||
-	    (d->x + d->width  >= vis_mode.virt.x) ||
-	    (d->y + d->height >= vis_mode.virt.y))
+	    (d->x + d->width  > vis_mode.virt.x) ||
+	    (d->y + d->height > vis_mode.virt.y))
 	{
 		fprintf(stderr, "teleserver: ILLEGAL GETBOX.\n");
 		return;
